package betterquesting.questing.tasks;

import betterquesting.api.placeholders.tasks.FactoryTaskPlaceholder;
import betterquesting.api.questing.tasks.ITask;
import betterquesting.api2.registry.IFactoryData;
import betterquesting.api2.registry.IRegistry;
import betterquesting.core.BetterQuesting;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.ResourceLocation;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_questing_tasks.jar:betterquesting/questing/tasks/TaskRegistry.class */
public class TaskRegistry implements IRegistry<IFactoryData<ITask, NBTTagCompound>, ITask> {
    public static final TaskRegistry INSTANCE = new TaskRegistry();
    private final HashMap<ResourceLocation, IFactoryData<ITask, NBTTagCompound>> taskRegistry = new HashMap<>();

    public void register(IFactoryData<ITask, NBTTagCompound> factory) {
        if (factory == null) {
            throw new NullPointerException("Tried to register null task");
        }
        if (factory.getRegistryName() == null) {
            throw new IllegalArgumentException("Tried to register a task with a null name: " + factory.getClass());
        }
        if (this.taskRegistry.containsKey(factory.getRegistryName()) || this.taskRegistry.containsValue(factory)) {
            throw new IllegalArgumentException("Cannot register dupliate task type: " + factory.getRegistryName());
        }
        this.taskRegistry.put(factory.getRegistryName(), factory);
    }

    /* renamed from: getFactory, reason: merged with bridge method [inline-methods] */
    public IFactoryData<ITask, NBTTagCompound> m2getFactory(ResourceLocation registryName) {
        return this.taskRegistry.get(registryName);
    }

    public List<IFactoryData<ITask, NBTTagCompound>> getAll() {
        return new ArrayList(this.taskRegistry.values());
    }

    /* renamed from: createNew, reason: merged with bridge method [inline-methods] */
    public ITask m1createNew(ResourceLocation registryName) {
        FactoryTaskPlaceholder m2getFactory;
        try {
            if (FactoryTaskPlaceholder.INSTANCE.getRegistryName().equals(registryName)) {
                m2getFactory = FactoryTaskPlaceholder.INSTANCE;
            } else {
                m2getFactory = m2getFactory(registryName);
            }
            if (m2getFactory == null) {
                BetterQuesting.logger.log(Level.ERROR, "Tried to load missing task type '" + registryName + "'! Are you missing an expansion pack?");
                return null;
            }
            return (ITask) m2getFactory.createNew();
        } catch (Exception e) {
            BetterQuesting.logger.log(Level.ERROR, "Unable to instatiate task: " + registryName, e);
            return null;
        }
    }
}
